@@ -62,8 +62,8 @@ class CGSmartImage extends CGExtensions
     $this->SetParameterType('noautoscale',CLEAN_INT);
     $this->CreateParameter('noautoscale','',$this->Lang('param_noautoscale'));
 
-    $this->SetParameterType('nocache',CLEAN_INT);
-    $this->CreateParameter('nocache','',$this->Lang('param_nocache'));
+    $this->SetParameterType('nobcache',CLEAN_INT);
+    $this->CreateParameter('nobcache','',$this->Lang('param_nobcache'));
 
     $this->SetParameterType('noembed',CLEAN_INT);
     $this->CreateParameter('noembed','',$this->Lang('param_noembed'));
@@ -137,6 +137,7 @@ class CGSmartImage extends CGExtensions
     $this->CreateParameter('filter_negate','',$this->Lang('param_filter_negate'));
     $this->CreateParameter('filter_pixelate','',$this->Lang('param_filter_pixelate'));
     $this->CreateParameter('filter_resize','',$this->Lang('param_filter_resize'));
+    $this->CreateParameter('filter_resizetofit','',$this->Lang('param_filter_resizetofit'));
     $this->CreateParameter('filter_rotate','',$this->Lang('param_filter_rotate'));
     $this->CreateParameter('filter_roundedcorners','',$this->Lang('param_filter_roundedcorners'));
     $this->CreateParameter('filter_watermark','',$this->Lang('param_filter_watermark'));
@@ -172,7 +173,7 @@ class CGSmartImage extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.5.1';
+    return '1.6.1';
   }
 
   
