@@ -87,6 +87,10 @@ class cgsi_utils
 		  }
 		$col = '';
 	      }
+	    else
+	      {
+		$col .= $str[$i];
+	      }
 	    break;
 
 	  case "'":
@@ -136,6 +140,58 @@ class cgsi_utils
   }
 
 
+  public static function color_to_rgb($str)
+  {
+    $str = trim($str);
+    $res = array(0,0,0);
+
+    if( startswith($str,'#') && strlen($str) == 7 )
+      {
+	$res[0] = hexdec(substr($str,1,2));
+	$res[1] = hexdec(substr($str,3,2));
+	$res[2] = hexdec(substr($str,5,2));
+	return $res;
+      }
+    
+    $tmp = explode(':',$str,3);
+    if( is_array($tmp) && count($tmp) == 3 && is_numeric($tmp[0]) && is_numeric($tmp[1]) && is_numeric($tmp[1]) )
+      {
+	$res[0] = (int)$tmp[0];
+	$res[1] = (int)$tmp[1];
+	$res[2] = (int)$tmp[2];
+	return $res;
+      }
+    
+    // assume it's a color name.
+    static $_colors;
+    if( !is_array($_colors) )
+      {
+	$fn = dirname(__FILE__).'/colors.dat';
+	$data = file($fn);
+	if( count($data) )
+	  {
+	    $_colors = array();
+	    for( $i = 0; $i < count($data); $i++ )
+	      {
+		list($rgb,$name) = explode('-',$data[$i],2);
+		if( !startswith($rgb,'#') || strlen($rgb) != 7 || $name == '' ) continue;
+
+		$tmp = array();
+		$tmp[0] = hexdec(substr($rgb,1,2));
+		$tmp[1] = hexdec(substr($rgb,3,2));
+		$tmp[2] = hexdec(substr($rgb,5,2));
+
+		$_colors[strtolower(trim($name))] = $tmp;
+	      }
+	  }
+      }
+    if( is_array($_colors) && isset($_colors[$str]) )
+      {
+	$res = $_colors[$str];
+      }
+    return $res;
+  }
+
   public static function &process_image($params)
   {
     $mod = cms_utils::get_module('CGSmartImage');
@@ -160,7 +216,7 @@ class cgsi_utils
     $outp['error'] = '';
     $opp = array();  // operation params
     $opp['overwrite'] = 0;
-    $opp['nocache'] = 0;
+    $opp['nobcache'] = 0;
     $opp['noremote'] = 0;
     $opp['noembed'] = 0;
     $opp['noauto'] = 0;
@@ -239,9 +295,9 @@ class cgsi_utils
 
 	switch( $key )
 	  {
+	  case 'class':
 	  case 'id':
 	  case 'style':
-	  case 'class':
 	  case 'name':
 	  case 'alt':
 	  case 'rel':
@@ -265,7 +321,7 @@ class cgsi_utils
 	  case 'overwrite':
 	  case 'notag':
 	  case 'noremote':
-	  case 'nocache':
+	  case 'nobcache':
 	  case 'noembed':
 	  case 'norotate':
 	    $opp[$key] = cge_utils::to_bool($value);
@@ -441,7 +497,6 @@ class cgsi_utils
     //
     // end of smartness stuff... now begin the work
     //
-
     if( !$outp['error'] && count(array_keys($opp['filters'])) )
       {
 	//
@@ -456,7 +511,7 @@ class cgsi_utils
 	$tmp = basename($srcfile);
 	$ext = strrchr($tmp,'.');
 	$t2 = md5(serialize($opp));
-	$destname = substr($tmp,0,strlen($tmp)-strlen($ext)).'-'.$t2.$ext;
+	$destname = substr($tmp,0,strlen($tmp)-strlen($ext)).'-'.$t2;
     
 	$destdir = $config['uploads_path'].'/_'.$mod->GetName();
 	if( !is_dir($destdir) ) @mkdir($destdir);
@@ -467,9 +522,9 @@ class cgsi_utils
 	else
 	  {
 	    // see if it exists
-	    $dest_fname = $destdir.'/'.$destname;
+	    $dest_fname = $destdir.'/'.$destname.$ext;
 
-	    $dest_url = $mod->get_cached_image_url($destname);
+	    $dest_url = $mod->get_cached_image_url($destname).$ext;
 	    if( !file_exists($dest_fname) || $opp['overwrite']  )
 	      {
 		$do_transform = 1;
@@ -482,7 +537,7 @@ class cgsi_utils
 	$dest_fname = $srcfile;
 	$dest_url = $opp['src'];
       }
-
+ 
     if( !$outp['error'] && $do_transform )
       {
 	try
@@ -497,13 +552,17 @@ class cgsi_utils
 		$filter = $opp['filters'][$i][0];
 		$filter_obj = new $filter($opp['filters'][$i][1]);
 		$img = $filter_obj->transform($img);
+		$img['dirty'] = 1; // force the image dirty, just so that we can save it.
 		$i++;
 	      }
 
 	    // and write the thing.
 	    if( !$outp['error'] && is_object($img) )
 	      {
-		$img->save($dest_fname,$opp['quality']);
+		if( $img['dirty'] )
+		  {
+		    $img->save($dest_fname,$opp['quality']);
+		  }
 	      }
 	  }
 	catch( Exception $e )
@@ -519,7 +578,7 @@ class cgsi_utils
       }
 
     // at this point, we're ready to handle building the tag.
-    if( $opp['nocache'] )
+    if( $opp['nobcache'] )
       {
 	$dest_url .= '?x='.time();      
       }
@@ -665,7 +724,7 @@ class cgsi_utils
 		continue;
 	      }
 
-	    if( startswith($params['src'],'data:') ) continue;   // already embedded, can't do anything.
+	    if( startswith($parms['src'],'data:') ) continue;   // already embedded, can't do anything.
 
 	    $parms['notag'] = 1;
 	    $outp = self::process_image($parms);
@@ -693,7 +752,6 @@ class cgsi_utils
     // get the contents.
     if( $did_modify )
       {
-	$content = '';
 	$node = $dom->documentElement;
 	$content = $node->innerHTML;
 	$content = str_replace(chr(13),'',$content);
